@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -45,6 +43,12 @@ namespace gbrainy.Core.Toolkit
 			if (y < 0 || y > 1)
 				throw new ArgumentOutOfRangeException ("y");
 
+			if (width + x < 0 || width + x > 1)
+				throw new ArgumentOutOfRangeException ("width");
+
+			if (height + y < 0 || height + y > 1)
+				throw new ArgumentOutOfRangeException ("height");
+
 			X = x;
 			Y = y;
 		}
@@ -66,7 +70,7 @@ namespace gbrainy.Core.Toolkit
 				OnDrawRequest ();
 			};
 
-			widget.SelectedEvent += delegate (object sender, SeletectedEventArgs e)
+			widget.SelectedEvent += delegate (object sender, SelectedEventArgs e)
 			{
 				OnSelected (e);
 			};
